#!/bin/bash

set -e

_run_psql() {
  psql -U postgres -t -c "$1"
}

get_var_from_environment() {
    if [[ -z "${MMUSER_DB_PASSWORD}" ]]; then
        echo "MMUSER_DB_PASSWORD environment variable not set, unable to create user, exiting with error"
        exit 1
    fi
}

create_db_and_user() {
    DB_EXISTS=$(_run_psql "SELECT 1 FROM pg_database WHERE datname='mattermost'")
    if [[ -z "${DB_EXISTS}" ]]; then
        _run_psql "CREATE DATABASE mattermost"
    fi

    USER_EXISTS=$(_run_psql "SELECT 1 FROM pg_roles WHERE rolname='mmuser'")
    if [[ -z "${USER_EXISTS}" ]]; then
        _run_psql "CREATE USER mmuser LOGIN PASSWORD '${MMUSER_DB_PASSWORD}'"
        _run_psql "ALTER DATABASE mattermost OWNER TO mmuser"
    else
        _run_psql "ALTER USER mmuser PASSWORD '${MMUSER_DB_PASSWORD}'"
    fi
}

save_execution() {
  DATETIME=$(date +"%m-%d-%Y-%H-%M-%S")
  echo "$0" "$DATETIME" >> "/var/lib/postgresql/data/external_update_executed.lists"
}

get_var_from_environment
create_db_and_user

echo "$0 update finished, mattermost db and user created"

save_execution